@@ -6,7 +6,7 @@ package Tk::FileTree;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 use Tk;
 use Tk::Derived;
@@ -834,27 +834,27 @@ Tk::FileTree - Tk::DirTree like widget for displaying & manipulating directories
 =head1 DESCRIPTION
 
 Creates a widget to display a file-system (or part of it) in a tree format.  
-Works very similar to Tk::DirTree, but displays both files and subdirectories.  
-Each subdirectory includes an indicator icon resembling [+] or [-] to either 
-expand and view it's contents (files and subdiretories) or collapse them 
-respectively.  A separate icon is displayed for files and subdirectories making 
-it easier to tell them apart.  Options allow users to select a file, a 
-directory, or multiple entries (like a listbox) which can be returned to the 
-program for further processing.
+Works very similar to L<Tk::DirTree>, but displays both files and 
+subdirectories by default.  Each subdirectory includes an indicator icon 
+resembling [+] or [-] to either expand and view it's contents (files and 
+subdiretories) or collapse them respectively.  A separate icon is displayed for 
+files and subdirectories making it easier to tell them apart.  Options allow 
+users to select a file, a directory, or multiple entries (like a listbox) which 
+can be returned to the program for further processing.
 
-This widget is derived from B<Tk::DirTree>B.  It provides additional features, 
+This widget is derived from B<Tk::DirTree>.  It provides additional features, 
 including listing files, in addition to the subdirectories, options (filters) 
 to limit which files are displayed (by specificy including or excluding a list 
-of file extensions), and additional bindings and functions to enable user-
-selection and interaction with specific files and directories from within 
+of file extensions), and additional bindings and functions to enable 
+user-selection and interaction with specific files and directories from within 
 other programs.
 
 I took Tk::DirTree, renamed it and modified it to create this module primarily 
 to be able to add a "tree-view" option to my Perl-Tk based filemanager 
-called JFM5, which allows users to select and perform common functions on files 
-and directories on their system and others (via B<Net::xFTP>).  I have created 
-other modules toward this effort, namely B<Tk::HMListbox> and 
-B<Tk::JThumbnail>.  These modules provide the different "views":  Detailed 
+called B<JFM5>, which allows users to select and perform common functions on 
+files and directories on their system, and others (via L<Net::xFTP>).  I have 
+previously created other modules toward this effort, namely L<Tk::HMListbox> 
+and L<Tk::JThumbnail>.  These modules provide the different "views":  Detailed 
 list, Image list, and now Tree-view, respectively.
 
 =head1 STANDARD OPTIONS
@@ -877,11 +877,35 @@ See L<Tk::options> for details of the standard options.
 
 =item Switch: B<-activeforeground>
 
-Specifies an alternate color for the foreground of the "active" entry (the one the text 
-cursor is on).  This entry is also shown with a hashed box around it.  
-The "activebackground" color, however, is always fixed as the same color as the 
-the widget's background.  
-Default:  same color as the widget's foreground color.
+Specifies an alternate color for the foreground of the "active" entry (the one 
+the text cursor is on).  This entry is also shown with a hashed box around it.  
+NOTE:  The "activebackground" color, however, is always fixed to the same color 
+as the widget's background, due to the fact that the underlying L<Tk::HList> 
+module only sets the text and icon areas to the active background, rather than 
+the entire row resulting in a somewhat ugly appearance if the row is "active" 
+but not "selected".  
+
+DEFAULT:  Same color as the widget's foreground color.
+
+=item Name: B<browseCmd>
+
+=item Class: B<BrowseCmd>
+
+=item Switch: B<-browsecmd>
+
+Specifies a callback to call whenever the user browses on a file or directory 
+(usually by single-clicking on the name). The callback is called with one 
+argument:  the complete pathname of the file / directory.
+
+=item Name: B<command>
+
+=item Class: B<Command>
+
+=item Switch: B<-command>
+
+Specifies the callback to be called when the user activates on a file or 
+directory (usually by double-clicking on the name).  The callback is called 
+with one argument, the complete pathname of the file / directory.
 
 =item Name: B<dirCmd>
 
@@ -891,9 +915,20 @@ Default:  same color as the widget's foreground color.
 
 Callback function to obtain the list of directories and files for display.  A 
 sensible default is provided and it should not be overridden unless you know 
-what you are doing.  It takes three arguments:  a widget object handle, a 
+what you are doing!  It takes three arguments:  a widget object handle, a 
 directory path, and a boolean value (TRUE for include hidden (dot) files or 
-FALSE to exclude them).
+FALSE to exclude them).  
+
+Tk::DirTree documentation:  Specifies the callback to be called when a 
+directory listing is needed for a particular directory.  If this option is not 
+specified, by default the DirTree widget will attempt to read the directory as 
+a Unix directory.  On special occasions, the application programmer may want to 
+supply a special method for reading directories: for example, when he needs to 
+list remote directories.  In this case, the B<-dircmd> option can be used.  
+The specified callback accepts two arguments:  the first is the name of the 
+directory to be listed; the second is a Boolean value indicating whether 
+hidden sub-directories should be listed. This callback returns a list of names 
+of the sub-directories of this directory.
 
 =item Name: B<dirTree>
 
@@ -903,7 +938,8 @@ FALSE to exclude them).
 
 Boolean option to only show directories (like Tk::DirTree) if TRUE, show both 
 directories and files if FALSE.  Use this to work as a drop-in replacement for 
-Tk::DirTree.
+Tk::DirTree.  To truly emulate Tk::DirTree's behavior, one should probably also 
+specify "-takefocus => 1", as that seems to be it's default focus model.
 
 DEFAULT:  I<FALSE> (Show both directories and files).
 
@@ -914,7 +950,7 @@ DEFAULT:  I<FALSE> (Show both directories and files).
 =item Switch:	B<-exclude>
 
 Specify a reference to an array of file-extensions to be excluded.  Note:  Not 
-applicable to directory names (case insensitive).
+applicable to directory names (case insensitive).  See also:  B<-include>.
 
 DEFAULT:  I<[]> (Do not exclude any files).
 
@@ -934,7 +970,10 @@ the B<-width> option.  See also:  B<-width>.
 =item Switch:	B<-fileimage>
 
 Specify an alternate xpm (tiny icon) image to be displayed to the left of each 
-file displayed which is not a directory).
+file displayed which is not a directory).  See also:  B<-image>.
+
+DEFAULT:  A sensible default icon of a white sheet of paper with a dogeared 
+corner is provided.
 
 =item Name: B<image>
 
@@ -943,7 +982,10 @@ file displayed which is not a directory).
 =item Switch:	B<-image>
 
 Specify an alternate xpm (tiny icon) image to be displayed to the left of each 
-directory).
+directory).  See also:  B<-fileimage>.
+
+DEFAULT:  A sensible default icon of a yellow folder is provided (the same one 
+used by Tk::DirTree).
 
 =item Name: B<include>
 
@@ -953,7 +995,7 @@ directory).
 
 Specify a reference to an array of file-extensions to be included, all other 
 entensions will be excluded.  Note:  Not applied to directory names 
-(case insensitive).
+(case insensitive).  See also:  B<-exclude>.
 
 DEFAULT:  I<[]> (Include all files).
 
@@ -1008,11 +1050,11 @@ Boolean option to include hidden (dot) files and directories (if TRUE),
 otherwise, exclude them.
 
 DEFAULT:  I<FALSE> (Exclude hidden directories and files (those that begin with 
-a dot (".").
+a dot (".")).
 
 =item Switch:	B<-state>
 
-Specifies one of two states for the tree widget: B<normal> or B<disabled>.  
+Specifies one of two states for the widget: B<normal> or B<disabled>.  
 If the widget is disabled then items may not be selected,
 items are drawn in the B<-disabledforeground> color, and selection
 cannot be modified and is not shown (though selection information is
@@ -1035,7 +1077,7 @@ the keyboard focus.  Disabling the widget will also prevent focus while
 disabled, but restore the previous focusing policy when re-enabled.  
 
 DEFAULT:  I<""> (Empty string, also a "false" value, the default Tk 
-focusing option, but different from I<0> (zero), as explained above.
+focusing option), but different from I<0> (zero), as explained above.
 
 =item Name:	B<width>
 
@@ -1091,23 +1133,25 @@ palette to be changed will also need to unpack, destroy, recreate, add the
 additional pair of images (with white foregrounds) and repack the FileTree 
 widget if it determines that the foreground color is being changed from black 
 to white (ie. palette has changed from a "light" to a "dark" background).  The 
-reason for this extra work is due to the fact that there is no know way to 
+reason for this extra work is due to the fact that there is no known way to 
 go through and reset and redraw all the icons displayed when the palette 
 is changed.  Tk does not include white-foreground bitmaps of these two images, 
-so the author of such a program will need to also create these two bitmaps 
-and include them in the Tk directory itself (ie. /usr/local/lib/site_perl/Tk)!
+so the author of such a program will need to either also create these two 
+bitmaps and include them in the Tk directory itself 
+(ie. /usr/local/lib/site_perl/Tk); or simply use the two corresponding 
+"*_night.xpm" icon images B<included> with this module!
 
 =item I<$widget>-E<gt>B<chdir>(I<full_directory_path> [, I<ops> ])
 
-Synonym for I<$widget>-E<gt>B<set_dir>()I<full_directory_path> [, I<ops> ] - 
-a holdover from Tk::DirTree.  See I<setdir> below.
+Synonym for I<$widget>-E<gt>B<set_dir>(I<full_directory_path> [, I<ops> ]) - 
+a holdover from Tk::DirTree.  See B<setdir> below.
 
 =item I<$widget>-E<gt>B<close>(I<index>)
 
 Collapses the display of the directory specified by I<index>, if it is a 
 directory and it is currently expanded (files and subdirectories are 
 currently displayed.  If successful, it also activates and scrolls the entry 
-into view.  See also I<$widget>-E<gt>B<open>(I<index>)
+into view.  See also the B<open> method.
 
 =item I<$widget>-E<gt>B<curselection>
 
@@ -1123,12 +1167,12 @@ Deletes one or all elements of the HListbox.  The "I<index>" must eiter be
 must be a full path-name to a file or directory in the tree or "I<all>", 
 meaning delete the entire tree.
 
-=item I<$widget>-E<gt>B<hide>([I<-entry> =<gt> ] I<index>)
+=item I<$widget>-E<gt>B<hide>([I<-entry> => ] I<index>)
 
 Given an I<index>, sets the entry to "hidden" so that it does not 
 display in the tree (but maintains it's index.  The "I<-entry>" 
 argument is unnecessary, but retained for Tk::HList compatability.  
-See also the I<show> method.
+See also the B<show> method.
 
 =item I<$widget>-E<gt>B<index>(I<index>)
 
@@ -1137,7 +1181,7 @@ Returns the "normalized" version of the entry that corresponds to I<index>.
 valid "*nix" format ("/" instead of "\"), any trailing "/" is removed 
 unless the path is "/" (root).  This can still be passed to any of the 
 public methods, which will ensure they're in the proper format for the 
-hosting operating system.  Two special values may also be given for 
+host operating system.  Two special values may also be given for 
 I<index>:  I<active> and I<anchor>, which are similar for I<Tk::HList>-based 
 widgets and return the current active element's index.  The subtle difference 
 is that "I<anchor>" is not valid when the widget is disabled, but "I<active>" 
@@ -1149,9 +1193,9 @@ Expands the display of the directory specified by I<index>, if it is a
 directory and it is currently collapsed (files and subdirectories are 
 currently not displayed.  If successful, it also activates and scrolls the 
 entry into view.  The optional I<ops> represents a hash of additional options.  
-Currently, the only valid value is "I<-silent => 1>", meaning just close, 
+Currently, the only valid value is "I<-silent =<gt> 1>", meaning just open, 
 but don't activate or scroll the window position.  
-See also I<$widget>-E<gt>B<open>(I<index>)
+See also the B<close> method.
 
 =item I<$widget>-E<gt>B<see>(I<index>)
 
@@ -1164,8 +1208,7 @@ or not a valid entry, this function is ignored.
 =item I<$widget>-E<gt>B<selectionClear>([I<index>])
 
 If I<index> is specified and it's element is currently selected, it will 
-be unselected.  The selection state is not changed for elements outside
-this range.  If no I<index> is specified, all selected items will be 
+be unselected.  If no I<index> is specified, all selected items will be 
 unselected, clearing the selection list.
 
 =item I<$widget>-E<gt>B<selectionIncludes>(I<index>)
@@ -1177,7 +1220,7 @@ selected, 0 if it isn't.
 
 Adds entry specified by I<index> to the selected list if it is not already 
 selected.  Note:  Unlike listboxes, etc. only a single element may be 
-selected per call.  Ranges are not accepted.
+selected per call.  Ranges are not accepted (ignored).
 
 =item I<$widget>-E<gt>B<selectionToggle>(I<index>)
 
@@ -1197,12 +1240,12 @@ $widget->set_dir("/home/user/documents", -root => "/home/user").  This
 would open the user "user"'s "documents" directory expanded, but not 
 permit him to expand either root ("/" or "/home" to see their contents.
 
-=item I<$widget>-E<gt>B<show>([I<-entry> =<gt> ] I<index>)
+=item I<$widget>-E<gt>B<show>([I<-entry> => ] I<index>)
 
 Given an I<index>, sets the hidden entry to visible so that it is 
 displayed in the tree (but maintains it's index.  The "I<-entry>" 
 argument is unnecessary, but retained for Tk::HList compatability.  
-See also the I<hide> method.
+See also the B<hide> method.
 
 =back
 
